@@ -12,7 +12,7 @@ use Data::Object::Library qw(Str);
 
 extends 'API::Client';
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 our $DEFAULT_URL = "https://a.wunderlist.com";
 
@@ -99,7 +99,7 @@ API::Wunderlist - Wunderlist.com API Client
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -167,7 +167,7 @@ The debug attribute if true prints HTTP requests and responses to standard out.
     $wunderlist->fatal(1);
 
 The fatal attribute if true promotes 4xx and 5xx server response codes to
-exceptions, a L<API::Wunderlist::Exception> object.
+exceptions, a L<API::Client::Exception> object.
 
 =head2 retries
 
